<?php $TRANSLATIONS = array(
"Access granted" => "Acesso concedido",
"Error configuring Dropbox storage" => "Erro ao configurar armazenamento do Dropbox",
"Grant access" => "Permitir acesso",
"Please provide a valid Dropbox app key and secret." => "Por favor forneça um app key e secret válido do Dropbox",
"Error configuring Google Drive storage" => "Erro ao configurar armazenamento do Google Drive",
"<b>Warning:</b> \"smbclient\" is not installed. Mounting of CIFS/SMB shares is not possible. Please ask your system administrator to install it." => "<b>Aviso:</b> \"smbclient\" não está instalado. Impossível montar compartilhamentos de CIFS/SMB. Por favor, peça ao seu administrador do sistema para instalá-lo.",
"<b>Warning:</b> The FTP support in PHP is not enabled or installed. Mounting of FTP shares is not possible. Please ask your system administrator to install it." => "<b>Aviso:</b> O suporte para FTP do PHP não está ativado ou instalado. Impossível montar compartilhamentos FTP. Por favor, peça ao seu administrador do sistema para instalá-lo.",
"External Storage" => "Armazenamento Externo",
"Folder name" => "Nome da pasta",
"External storage" => "Armazenamento Externo",
"Configuration" => "Configuração",
"Options" => "Opções",
"Applicable" => "Aplicável",
"Add storage" => "Adicionar Armazenamento",
"None set" => "Nenhum definido",
"All Users" => "Todos os Usuários",
"Groups" => "Grupos",
"Users" => "Usuários",
"Delete" => "Remover",
"Enable User External Storage" => "Habilitar Armazenamento Externo do Usuário",
"Allow users to mount their own external storage" => "Permitir usuários a montar seus próprios armazenamentos externos",
"SSL root certificates" => "Certificados SSL raíz",
"Import Root Certificate" => "Importar Certificado Raíz"
);
